#!/bin/bash

# Check our arguments
while getopts ":d:DF:m:M:p:s:u:" opt; do
	case $opt in
		# Just backup this DB
		d) DB=$OPTARG ;;

		D) DEBUG=1 ;;

		# Filespace to store in TSM
		F) FILESPACE=$OPTARG ;;

		# Digest to use
		M) DIGEST=$OPTARG ;;

		# Optional MYSQL arguments
		m) MYSQL_ARGS=$OPTARG ;;

		# Mysql PASSWORD
		p) DBPASS=$OPTARG ;;

		# Skip DBs
		s) SKIP_DB=$OPTARG ;;

		# Mysql USERNAME
		u) DBUSER=$OPTARG ;;

		# Error Checking
		\?)
			echo "Invalid option: -$OPTARG" >&2
			exit 1
			;;
		:)
			echo "Option -$OPTARG requires an argument." >&2
			exit 1
			;;
	esac
done

# Our defaults
FILESPACE=${FILESPACE:-"/mysqldump"}
MYSQL_ARGS=${MYSQL_ARGS:-"-K --skip-extended-insert --skip-dump-date"}

[ -n "$DBPASS" ] && MYSQL_AUTH="-p${DBPASS}"
[ -n "$DBUSER" ] && MYSQL_AUTH="-u${DBUSER} ${MYSQL_AUTH}"

# List our Databases
function listdb() {
	echo "show databases" |mysql -N ${MYSQL_AUTH}
}

# Get Size
function getsize() {
	echo "SELECT sum(data_length+index_length) FROM information_schema.TABLES where table_schema=\"$1\" GROUP BY table_schema ; " | mysql -N ${MYSQL_AUTH}
}

# TSMPIPE ARGUMENTS
[ -n "$DIGEST" ] && TSMPIPE_ARGS="${TSMPIPE_ARGS} -m ${DIGEST}"

listdb | while read db; do
	[ -n "$DB" -a "$db" != "$DB" ] && continue;

	if [ -n "$SKIP_DB" ]; then
		OLDIFS=$IFS
		IFS=":"
		SKIP=0
		for x in $SKIP_DB ; do
			[ $x == $db ] && SKIP=1 && break
		done
		IFS=$OLDIFS
	fi

	# We need to skip this DB
	[ "$SKIP" -eq 1 ] && continue;

	size=$(getsize $db);

	[ -n "$DEBUG" ] && echo "Processing DB ($db), with size ($size)"

	# Backup to TSM
	mysqldump ${MYSQL_AUTH} ${MYSQL_ARGS} $db| tsmpipe -Bcs ${FILESPACE} -f ${db}.FULL -l ${size} ${TSMPIPE_ARGS}
done;
